pub struct Wast<'a> {
pub source_filename: Cow<'a, str>,
pub commands: Vec<Command<'a>>,
pub wasms: Vec<(String, Vec<u8>)>,
}Expand description
Top level *.wast structure.
Fields
source_filename: Cow<'a, str>commands: Vec<Command<'a>>wasms: Vec<(String, Vec<u8>)>This field is only present when created via Wast::from_ast and
contains the collection of wasm modules, and their names, that should
be emitted.
Implementations
Sourceimpl<'a> Wast<'a>
impl<'a> Wast<'a>
Sourcepub fn from_ast(
source_filename: &'a str,
source_contents: &'a str,
ast: Wast<'a>,
) -> Result<Wast<'a>>
pub fn from_ast( source_filename: &'a str, source_contents: &'a str, ast: Wast<'a>, ) -> Result<Wast<'a>>
Parses the wast::Wast into Wast of this crate, serializing all
modules for example to binary.
The source_filename is used in the returned Wast object and
source_contents is the original file used for line numbers.